Miscellaneous codepages
-----------------------

| file            | source
|-----------------|-------------------------------------------------------
| `NEXTSTEP.TXT`  | https://www.unicode.org/Public/MAPPINGS/VENDORS/NEXT/
| `GSM0338.TXT`   | https://www.unicode.org/Public/MAPPINGS/ETSI/
| `ibm-ugl.txt`   | https://www.borgendale.com/glyphs.htm
| `dashen-map.txt`| contributed by Daniel Yacob
| all others      | https://www.unicode.org/Public/MAPPINGS/VENDORS/MISC/
